@@ -1,7 +1,7 @@
 /*
 **  OSSP uuid - Universally Unique Identifier
-**  Copyright (c) 2004-2006 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2004-2006 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2004-2008 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2004-2008 The OSSP Project <http://www.ossp.org/>
 **
 **  This file is part of OSSP uuid, a library for the generation
 **  of UUIDs which can found at http://www.ossp.org/pkg/lib/uuid/
@@ -28,8 +28,8 @@
 */
 
 /* own headers (part 1/2) */
-#include "config.h"
 #include "uuid.h"
+#include "uuid_ac.h"
 
 /* system headers */
 #include <stdio.h>
@@ -49,6 +49,7 @@
 #include "uuid_sha1.h"
 #include "uuid_prng.h"
 #include "uuid_mac.h"
+#include "uuid_time.h"
 #include "uuid_ui64.h"
 #include "uuid_ui128.h"
 #include "uuid_str.h"
@@ -328,20 +329,24 @@ static uuid_rc_t uuid_import_bin(uuid_t *uuid, const void *data_ptr, size_t data
 
 /* INTERNAL: pack UUID object into binary representation
    (allows in-place operation for internal efficiency!) */
-static uuid_rc_t uuid_export_bin(const uuid_t *uuid, void **data_ptr, size_t *data_len)
+static uuid_rc_t uuid_export_bin(const uuid_t *uuid, void *_data_ptr, size_t *data_len)
 {
+    uuid_uint8_t **data_ptr;
     uuid_uint8_t *out;
     uuid_uint32_t tmp32;
     uuid_uint16_t tmp16;
     unsigned int i;
 
+    /* cast generic data pointer to particular pointer to pointer type */
+    data_ptr = (uuid_uint8_t **)_data_ptr;
+
     /* sanity check argument(s) */
     if (uuid == NULL || data_ptr == NULL)
         return UUID_RC_ARG;
 
     /* optionally allocate octet data buffer */
     if (*data_ptr == NULL) {
-        if ((*data_ptr = malloc(sizeof(uuid_t))) == NULL)
+        if ((*data_ptr = (uuid_uint8_t *)malloc(sizeof(uuid_t))) == NULL)
             return UUID_RC_MEM;
         if (data_len != NULL)
             *data_len = UUID_LEN_BIN;
@@ -355,7 +360,7 @@ static uuid_rc_t uuid_export_bin(const uuid_t *uuid, void **data_ptr, size_t *da
     }
 
     /* treat output data buffer as octet stream */
-    out = (uuid_uint8_t *)(*data_ptr);
+    out = *data_ptr;
 
     /* pack "time_low" field */
     tmp32 = uuid->obj.time_low;
@@ -492,10 +497,14 @@ static uuid_rc_t uuid_import_siv(uuid_t *uuid, const void *data_ptr, size_t data
 }
 
 /* INTERNAL: export UUID object to string representation */
-static uuid_rc_t uuid_export_str(const uuid_t *uuid, void **data_ptr, size_t *data_len)
+static uuid_rc_t uuid_export_str(const uuid_t *uuid, void *_data_ptr, size_t *data_len)
 {
+    char **data_ptr;
     char *data_buf;
 
+    /* cast generic data pointer to particular pointer to pointer type */
+    data_ptr = (char **)_data_ptr;
+
     /* sanity check argument(s) */
     if (uuid == NULL || data_ptr == NULL)
         return UUID_RC_ARG;
@@ -543,8 +552,9 @@ static uuid_rc_t uuid_export_str(const uuid_t *uuid, void **data_ptr, size_t *da
 }
 
 /* INTERNAL: export UUID object to single integer value representation */
-static uuid_rc_t uuid_export_siv(const uuid_t *uuid, void **data_ptr, size_t *data_len)
+static uuid_rc_t uuid_export_siv(const uuid_t *uuid, void *_data_ptr, size_t *data_len)
 {
+    char **data_ptr;
     char *data_buf;
     void *tmp_ptr;
     size_t tmp_len;
@@ -553,6 +563,9 @@ static uuid_rc_t uuid_export_siv(const uuid_t *uuid, void **data_ptr, size_t *da
     uuid_rc_t rc;
     int i;
 
+    /* cast generic data pointer to particular pointer to pointer type */
+    data_ptr = (char **)_data_ptr;
+
     /* sanity check argument(s) */
     if (uuid == NULL || data_ptr == NULL)
         return UUID_RC_ARG;
@@ -621,8 +634,9 @@ static struct {
 };
 
 /* INTERNAL: dump UUID object as descriptive text */
-static uuid_rc_t uuid_export_txt(const uuid_t *uuid, void **data_ptr, size_t *data_len)
+static uuid_rc_t uuid_export_txt(const uuid_t *uuid, void *_data_ptr, size_t *data_len)
 {
+    char **data_ptr;
     uuid_rc_t rc;
     char **out;
     char *out_ptr;
@@ -648,6 +662,9 @@ static uuid_rc_t uuid_export_txt(const uuid_t *uuid, void **data_ptr, size_t *da
     struct tm *tm;
     int i;
 
+    /* cast generic data pointer to particular pointer to pointer type */
+    data_ptr = (char **)_data_ptr;
+
     /* sanity check argument(s) */
     if (uuid == NULL || data_ptr == NULL)
         return UUID_RC_ARG;
@@ -820,7 +837,7 @@ uuid_rc_t uuid_import(uuid_t *uuid, uuid_fmt_t fmt, const void *data_ptr, size_t
 }
 
 /* UUID exporting */
-uuid_rc_t uuid_export(const uuid_t *uuid, uuid_fmt_t fmt, void **data_ptr, size_t *data_len)
+uuid_rc_t uuid_export(const uuid_t *uuid, uuid_fmt_t fmt, void *data_ptr, size_t *data_len)
 {
     uuid_rc_t rc;
 
@@ -857,11 +874,6 @@ static void uuid_brand(uuid_t *uuid, unsigned int version)
 static uuid_rc_t uuid_make_v1(uuid_t *uuid, unsigned int mode, va_list ap)
 {
     struct timeval time_now;
-#ifdef HAVE_NANOSLEEP
-    struct timespec ts;
-#else
-    struct timeval tv;
-#endif
     ui64_t t;
     ui64_t offset;
     ui64_t ov;
@@ -874,7 +886,7 @@ static uuid_rc_t uuid_make_v1(uuid_t *uuid, unsigned int mode, va_list ap)
     /* determine current system time and sequence counter */
     for (;;) {
         /* determine current system time */
-        if (gettimeofday(&time_now, NULL) == -1)
+        if (time_gettimeofday(&time_now) == -1)
             return UUID_RC_SYS;
 
         /* check whether system time changed since last retrieve */
@@ -894,17 +906,7 @@ static uuid_rc_t uuid_make_v1(uuid_t *uuid, unsigned int mode, va_list ap)
 
         /* stall the UUID generation until the system clock (which
            has a gettimeofday(2) resolution of 1us) catches up */
-#ifdef HAVE_NANOSLEEP
-        /* sleep for 500ns (1/2us) */
-        ts.tv_sec  = 0;
-        ts.tv_nsec = 500;
-        nanosleep(&ts, NULL);
-#else
-        /* sleep for 1000ns (1us) */
-        tv.tv_sec  = 0;
-        tv.tv_usec = 1;
-        select(0, NULL, NULL, NULL, &tv);
-#endif
+        time_usleep(1);
     }
 
     /* convert from timeval (sec,usec) to OSSP ui64 (100*nsec) format */
