@@ -1,7 +1,7 @@
 /*
 **  OSSP uuid - Universally Unique Identifier
-**  Copyright (c) 2004-2006 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2004-2006 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2004-2008 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2004-2008 The OSSP Project <http://www.ossp.org/>
 **
 **  This file is part of OSSP uuid, a library for the generation
 **  of UUIDs which can found at http://www.ossp.org/pkg/lib/uuid/
@@ -27,13 +27,24 @@
 **  uuid_prng.c: PRNG API implementation
 */
 
+/* own headers (part 1/2) */
+#include "uuid_ac.h"
+
+/* system headers */
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 #include <time.h>
 #include <sys/time.h>
 #include <fcntl.h>
+#if defined(WIN32)
+#define WINVER 0x0500
+#include <windows.h>
+#include <wincrypt.h>
+#endif
 
+/* own headers (part 2/2) */
+#include "uuid_time.h"
 #include "uuid_prng.h"
 #include "uuid_md5.h"
 
@@ -45,7 +56,9 @@ struct prng_st {
 
 prng_rc_t prng_create(prng_t **prng)
 {
+#if !defined(WIN32)
     int fd = -1;
+#endif
     struct timeval tv;
     pid_t pid;
     unsigned int i;
@@ -60,12 +73,14 @@ prng_rc_t prng_create(prng_t **prng)
 
     /* try to open the system PRNG device */
     (*prng)->dev = -1;
+#if !defined(WIN32)
     if ((fd = open("/dev/urandom", O_RDONLY)) == -1)
         fd = open("/dev/random", O_RDONLY|O_NONBLOCK);
     if (fd != -1) {
         (void)fcntl(fd, F_SETFD, FD_CLOEXEC);
         (*prng)->dev = fd;
     }
+#endif
 
     /* initialize MD5 engine */
     if (md5_create(&((*prng)->md5)) != MD5_RC_OK) {
@@ -77,7 +92,7 @@ prng_rc_t prng_create(prng_t **prng)
     (*prng)->cnt = 0;
 
     /* seed the C library PRNG once */
-    (void)gettimeofday(&tv, NULL);
+    (void)time_gettimeofday(&tv);
     pid = getpid();
     srand((unsigned int)(
         ((unsigned int)pid << 16)
@@ -104,6 +119,9 @@ prng_rc_t prng_data(prng_t *prng, void *data_ptr, size_t data_len)
     size_t md5_len;
     int retries;
     int i;
+#if defined(WIN32)
+    HCRYPTPROV hProv;
+#endif
 
     /* sanity check argument(s) */
     if (prng == NULL || data_len == 0)
@@ -128,13 +146,19 @@ prng_rc_t prng_data(prng_t *prng, void *data_ptr, size_t data_len)
             p += (unsigned int)i;
         }
     }
+#if defined(WIN32)
+    else {
+        if (CryptAcquireContext(&hProv, NULL, NULL, PROV_RSA_FULL, 0))
+            CryptGenRandom(hProv, n, p);
+    }
+#endif
 
     /* approach 2: try to gather data via weaker libc PRNG API. */
     while (n > 0) {
         /* gather new entropy */
-        (void)gettimeofday(&(entropy.tv), NULL);            /* source: libc time */
-        entropy.rnd = rand();                               /* source: libc PRNG */
-        entropy.cnt = prng->cnt++;                          /* source: local counter */
+        (void)time_gettimeofday(&(entropy.tv));  /* source: libc time */
+        entropy.rnd = rand();                    /* source: libc PRNG */
+        entropy.cnt = prng->cnt++;               /* source: local counter */
 
         /* pass entropy into MD5 engine */
         if (md5_update(prng->md5, (void *)&entropy, sizeof(entropy)) != MD5_RC_OK)
