@@ -1,7 +1,7 @@
 /*
 **  OSSP uuid - Universally Unique Identifier
-**  Copyright (c) 2004-2005 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2004-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2004-2008 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2004-2008 The OSSP Project <http://www.ossp.org/>
 **
 **  This file is part of OSSP uuid, a library for the generation
 **  of UUIDs which can found at http://www.ossp.org/pkg/lib/uuid/
@@ -48,12 +48,16 @@
  * o Ralf S. Engelschall <rse@engelschall.com> (1999, for OSSP)
  */
 
+/* own headers (part 1/2) */
+#include "uuid_ac.h"
+
+/* system headers */
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "config.h"
+/* own headers (part 2/2) */
 #include "uuid_str.h"
 
 #if HAVE_LONG_LONG
@@ -100,7 +104,7 @@ static void dopr_outch (char *, size_t *, size_t, int);
 
 /* some handy macros */
 #define char_to_int(p) (p - '0')
-#define MAX(p,q) ((p >= q) ? p : q)
+#define STR_MAX(p,q) ((p >= q) ? p : q)
 #define NUL '\0'
 
 static void
@@ -281,6 +285,7 @@ dopr(
                 break;
             case 'E':
                 flags |= DP_F_UP;
+                /* FALLTHROUGH */
             case 'e':
                 if (cflags == DP_C_LDOUBLE)
                     fvalue = va_arg(args, LDOUBLE);
@@ -289,6 +294,7 @@ dopr(
                 break;
             case 'G':
                 flags |= DP_F_UP;
+                /* FALLTHROUGH */
             case 'g':
                 if (cflags == DP_C_LDOUBLE)
                     fvalue = va_arg(args, LDOUBLE);
@@ -322,7 +328,7 @@ dopr(
                     num = va_arg(args, LLONG *);
                     *num = (LLONG) currlen;
                 } else {
-                    int    *num;
+                    int *num;
                     num = va_arg(args, int *);
                     *num = currlen;
                 }
@@ -440,13 +446,13 @@ fmtint(
     convert[place] = 0;
 
     zpadlen = max - place;
-    spadlen = min - MAX(max, place) - (signvalue ? 1 : 0);
+    spadlen = min - STR_MAX(max, place) - (signvalue ? 1 : 0);
     if (zpadlen < 0)
         zpadlen = 0;
     if (spadlen < 0)
         spadlen = 0;
     if (flags & DP_F_ZERO) {
-        zpadlen = MAX(zpadlen, spadlen);
+        zpadlen = STR_MAX(zpadlen, spadlen);
         spadlen = 0;
     }
     if (flags & DP_F_MINUS)
@@ -688,8 +694,10 @@ str_vasprintf(
 {
     char *rv;
     int n;
+    va_list ap_tmp;
 
-    n = str_vsnprintf(NULL, 0, fmt, ap);
+    va_copy(ap_tmp, ap);
+    n = str_vsnprintf(NULL, 0, fmt, ap_tmp);
     if ((rv = (char *)malloc(n+1)) == NULL)
         return NULL;
     str_vsnprintf(rv, n+1, fmt, ap);
@@ -718,6 +726,7 @@ str_vrsprintf(
 {
     int rv;
     size_t n;
+    va_list ap_tmp;
 
     if (str == NULL)
         return -1;
@@ -726,8 +735,9 @@ str_vrsprintf(
         rv = strlen(*str);
     }
     else {
+        va_copy(ap_tmp, ap);
         n = strlen(*str);
-        rv = str_vsnprintf(NULL, 0, fmt, ap);
+        rv = str_vsnprintf(NULL, 0, fmt, ap_tmp);
         if ((*str = (char *)realloc(*str, n+rv+1)) == NULL)
             return -1;
         str_vsnprintf((*str)+n, rv+1, fmt, ap);
